# totob12-lib

i've got no clue what i'm doing

### Installation
```
pip install totob12
```

### Get started
How to multiply one number by another with this lib:

```Python
from totob12 import Multiplication

# Instantiate a Multiplication object
multiplication = Multiplication(2)

# Call the multiply method
result = multiplication.multiply(5)
```